# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`wireguard`](#wireguard): manages the wireguard package

### Defined types

* [`wireguard::interface`](#wireguardinterface): manages a wireguard setup

### Data types

* [`Wireguard::Peers`](#wireguardpeers): custom data type for an array with wireguard peers

## Classes

### <a name="wireguard"></a>`wireguard`

manages the wireguard package

#### Parameters

The following parameters are available in the `wireguard` class:

* [`manage_package`](#manage_package)
* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)
* [`config_directory`](#config_directory)
* [`purge_unknown_keys`](#purge_unknown_keys)
* [`interfaces`](#interfaces)

##### <a name="manage_package"></a>`manage_package`

Data type: `Boolean`

if the package should be managed or not

Default value: ``true``

##### <a name="package_name"></a>`package_name`

Data type: `String[1]`

the name of the package

Default value: `'wireguard-tools'`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Enum['installed', 'latest', 'absent']`

the ensure state of the package

Default value: `'installed'`

##### <a name="config_directory"></a>`config_directory`

Data type: `Stdlib::Absolutepath`

the path to the wireguard directory

Default value: `'/etc/wireguard'`

##### <a name="purge_unknown_keys"></a>`purge_unknown_keys`

Data type: `Boolean`

by default Puppet will purge unknown wireguard keys from `$config_directory`

Default value: ``true``

##### <a name="interfaces"></a>`interfaces`

Data type: `Hash[String[1], Any]`

hash of interfaces to create. Provides hiera integration.

Default value: `{}`

## Defined types

### <a name="wireguardinterface"></a>`wireguard::interface`

}

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.netdev.html#%5BWireGuardPeer%5D%20Section%20Options

#### Examples

##### Peer with one node and setup dualstack firewall rules

```puppet
wireguard::interface {'as2273':
  source_addresses => ['2003:4f8:c17:4cf::1', '149.9.255.4'],
  public_key       => 'BcxLll1BVxGQ5DeijroesjroiesjrjvX+EBhS4vcDn0R0=',
  endpoint         => 'wg.example.com:53668',
  addresses        => [{'Address' => '192.168.123.6/30',},{'Address' => 'fe80::beef:1/64'},],
}
```

##### Peer with one node and setup dualstack firewall rules with peers in a different layer2

```puppet
wireguard::interface {'as2273':
  source_addresses => ['2003:4f8:c17:4cf::1', '149.9.255.4'],
  public_key       => 'BcxLll1BVxGQ5DeijroesjroiesjrjvX+EBhS4vcDn0R0=',
  endpoint         => 'wg.example.com:53668',
  addresses        => [{'Address' => '192.168.218.87/32', 'Peer' => '172.20.53.97/32'}, {'Address' => 'fe80::ade1/64',},],
}
```

##### Create a passive wireguard interface that listens for incoming connections. Useful when the other side has a dynamic IP / is behind NAT

```puppet
wireguard::interface {'as2273':
  source_addresses => ['2003:4f8:c17:4cf::1', '149.9.255.4'],
  public_key       => 'BcxLll1BVxGQ5DeijroesjroiesjrjvX+EBhS4vcDn0R0=',
  dport            => 53668,
  addresses        => [{'Address' => '192.168.218.87/32', 'Peer' => '172.20.53.97/32'}, {'Address' => 'fe80::ade1/64',},],
}
```

##### create a wireguard interface behind a DSL line with changing IP with lowered MTU

```puppet
wireguard::interface {'as3668-2':
  source_addresses      => ['144.76.249.220', '2a01:4f8:171:1152::12'],
  public_key            => 'Tci/bHoPCjTpYv8bw17xQ7P4OdqzGpEN+NDueNjUvBA=',
  endpoint              => 'router02.bastelfreak.org:1338',
  dport                 => 1338,
  input_interface       => $facts['networking']['primary'],
  addresses             => [{'Address' => '169.254.0.10/32', 'Peer' =>'169.254.0.9/32'},{'Address' => 'fe80::beef:f/64'},],
  destination_addresses => [],
  persistent_keepalive  => 5,
  mtu                   => 1412,
```

##### create a wireguard interface with multiple peers

```puppet
wireguard::interface { 'wg0':
  dport     => 1338,
  addresses => [{'Address' => '192.0.2.1/24'}],
  peers     => [
    {
       public_key  => 'foo==',
       allowed_ips => ['192.0.2.2'],
    },
    {
       public_key  => 'bar==',
       allowed_ips => ['192.0.2.3'],
    }
  ],
}
```

#### Parameters

The following parameters are available in the `wireguard::interface` defined type:

* [`interface`](#interface)
* [`input_interface`](#input_interface)
* [`manage_firewall`](#manage_firewall)
* [`dport`](#dport)
* [`source_addresses`](#source_addresses)
* [`destination_addresses`](#destination_addresses)
* [`public_key`](#public_key)
* [`endpoint`](#endpoint)
* [`addresses`](#addresses)
* [`persistent_keepalive`](#persistent_keepalive)
* [`description`](#description)
* [`mtu`](#mtu)
* [`peers`](#peers)
* [`routes`](#routes)
* [`private_key`](#private_key)

##### <a name="interface"></a>`interface`

Data type: `String[1]`

the title of the defined resource, will be used for the wg interface

Default value: `$title`

##### <a name="input_interface"></a>`input_interface`

Data type: `String[1]`

ethernet interface where the wireguard packages will enter the system, used for firewall rules

Default value: `$facts['networking']['primary']`

##### <a name="manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

if true, a ferm rule will be created

Default value: ``true``

##### <a name="dport"></a>`dport`

Data type: `Integer[1024, 65000]`

destination for firewall rules / where our wg instance will listen on. defaults to the last digits from the title

Default value: `Integer(regsubst($title, '^\D+(\d+)$', '\1'))`

##### <a name="source_addresses"></a>`source_addresses`

Data type: `Array[Stdlib::IP::Address]`

an array of ip addresses from where we receive wireguard connections

Default value: `[]`

##### <a name="destination_addresses"></a>`destination_addresses`

Data type: `Array[Stdlib::IP::Address]`

array of addresses where the remote peer connects to (our local ips), used for firewalling

Default value: `[$facts['networking']['ip'], $facts['networking']['ip6'],]`

##### <a name="public_key"></a>`public_key`

Data type: `Optional[String[1]]`

base64 encoded pubkey from the remote peer

Default value: ``undef``

##### <a name="endpoint"></a>`endpoint`

Data type: `Optional[String[1]]`

fqdn:port or ip:port where we connect to

Default value: ``undef``

##### <a name="addresses"></a>`addresses`

Data type: `Array[Hash[String,Variant[Stdlib::IP::Address::V4::CIDR,Stdlib::IP::Address::V6::CIDR]]]`

different addresses for the systemd-networkd configuration

Default value: `[]`

##### <a name="persistent_keepalive"></a>`persistent_keepalive`

Data type: `Integer[0, 65535]`

is set to 1 or greater, that's the interval in seconds wireguard sends a keepalive to the other peer(s). Useful if the sender is behind a NAT gateway or has a dynamic ip address

Default value: `0`

##### <a name="description"></a>`description`

Data type: `Optional[String[1]]`

an optional string that will be added to the wireguard network interface

Default value: ``undef``

##### <a name="mtu"></a>`mtu`

Data type: `Optional[Integer[1280, 9000]]`

configure the MTU (maximum transision unit) for the wireguard tunnel. By default linux will figure this out. You might need to lower it if you're connection through a DSL line. MTU needs to be equal on both tunnel endpoints

Default value: ``undef``

##### <a name="peers"></a>`peers`

Data type: `Wireguard::Peers`

is an array of struct (Wireguard::Peers) for multiple peers

Default value: `[]`

##### <a name="routes"></a>`routes`

Data type: `Array[Hash[String[1], Variant[String[1], Boolean]]]`

different routes for the systemd-networkd configuration

Default value: `[]`

##### <a name="private_key"></a>`private_key`

Data type: `Optional[String[1]]`

Define private key which should be used for this interface, if not provided a private key will be generated

Default value: ``undef``

## Data types

### <a name="wireguardpeers"></a>`Wireguard::Peers`

custom data type for an array with wireguard peers

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.netdev.html#%5BWireGuardPeer%5D%20Section%20Options

Alias of

```puppet
Array[Struct[{
    public_key           => String[1],
    allowed_ips          => Optional[Array[String[1]]],
    endpoint             => Optional[String[1]],
    persistent_keepalive => Optional[Stdlib::Port],
    description          => Optional[String[1]],
  }]]
```

